@@ -1,12 +1,12 @@
 toLatex.ftable <- function(object,
           show.titles=TRUE,
-          digits=0,
-          format="f",
-          useDcolumn=TRUE,
+          digits=if(is.integer(object)) 0 else getOption("digits"),
+          format=if(is.integer(object)) "d" else "f",
+          useDcolumn=getOption("useDcolumn",TRUE),
           colspec=if(useDcolumn) paste("D{.}{",LaTeXdec,"}{",ddigits,"}",sep="") else "r",
           LaTeXdec=".",
           ddigits=digits,
-          useBooktabs=TRUE,
+          useBooktabs=getOption("useBooktabs",TRUE),
           toprule=if(useBooktabs) "\\toprule" else "\\hline\\hline",
           midrule=if(useBooktabs) "\\midrule" else "\\hline\n",
           cmidrule=if(useBooktabs) "\\cmidrule" else "\\cline",
