@@ -5,11 +5,11 @@ toLatex.matrix <- function(object,
           show.yvar=show.vars,
           digits=if(is.table(object)) 0 else getOption("digits"),
           format="f",
-          useDcolumn=TRUE,
+          useDcolumn=getOption("useDcolumn",TRUE),
           colspec=if(useDcolumn) paste("D{.}{",LaTeXdec,"}{",ddigits,"}",sep="") else "r",
           LaTeXdec=".",
           ddigits=digits,
-          useBooktabs=TRUE,
+          useBooktabs=getOption("useBooktabs",TRUE),
           toprule=if(useBooktabs) "\\toprule" else "\\hline\\hline",
           midrule=if(useBooktabs) "\\midrule" else "\\hline",
           cmidrule=if(useBooktabs) "\\cmidrule" else "\\cline",
@@ -96,4 +96,4 @@ toLatex.matrix <- function(object,
   structure(ans,class="Latex")
 }
 
-toLatex.default <- function(object,...) toLatex.matrix(as.matrix(object),...)
\ No newline at end of file
+toLatex.default <- function(object,...) toLatex.matrix(as.matrix(object),...)
